(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory(require('html2canvas')) :
    typeof define === 'function' && define.amd ? define(['html2canvas'], factory) :
    (global = global || self, global.shotify = factory(global.html2canvas));
}(this, function (html2canvas) { 'use strict';

    html2canvas = html2canvas && html2canvas.hasOwnProperty('default') ? html2canvas['default'] : html2canvas;

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0

    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.

    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */

    var __assign = function() {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };

    var AnnotationType;
    (function (AnnotationType) {
        AnnotationType["Highlight"] = "highlight";
        AnnotationType["Blackout"] = "blackout";
    })(AnnotationType || (AnnotationType = {}));
    var AnnotationHelper = /** @class */ (function () {
        function AnnotationHelper() {
            this.annotationType = AnnotationType.Highlight;
            this.annotations = [];
            this.annotationId = 0;
        }
        AnnotationHelper.prototype.createAnnotation = function (data) {
            var annotation = __assign(__assign({}, data), { type: this.annotationType, id: this.annotationId++ });
            if (annotation.width < 0) {
                annotation.x += annotation.width;
                annotation.width *= -1;
            }
            if (annotation.height < 0) {
                annotation.y += annotation.height;
                annotation.height *= -1;
            }
            this.annotations.push(annotation);
            return annotation;
        };
        return AnnotationHelper;
    }());
    var Shotify = /** @class */ (function () {
        function Shotify(options) {
            var _this = this;
            this.isProcessing = false;
            this.isAlertInfoShown = false;
            this.drawStartListener = function (event) {
                if (_this.isDrawingAllowed) {
                    _this.isDrawing = true;
                    _this.area = {
                        x: event.clientX + document.documentElement.scrollLeft,
                        y: event.clientY + document.documentElement.scrollTop,
                        width: 0,
                        height: 0
                    };
                }
            };
            this.drawStopListener = function (event) {
                if (_this.isDrawingAllowed) {
                    _this.isDrawing = false;
                    // TODO: need to check these magic numbers
                    if (Math.abs(_this.area.width) < 6 || Math.abs(_this.area.height) < 6) {
                        return;
                    }
                    var annotation = _this.annotationHelper.createAnnotation(_this.area);
                    annotation.element = _this.createHelperDiv(annotation);
                    _this.resetArea();
                    _this.repaint();
                }
            };
            this.saveHighlightAnnotation = function (event) {
                var area = _this.annotationHelper.annotationArea;
                if (area) {
                    // TODO: need to check these magic numbers
                    if (Math.abs(area.width) < 6 || Math.abs(area.height) < 6) {
                        return;
                    }
                    var annotation = _this.annotationHelper.createAnnotation(area);
                    annotation.element = _this.createHelperDiv(annotation);
                }
            };
            this.highlightAnnotation = function (event) {
                _this.annotationHelper.annotationArea = null;
                // We need the 3rd element in the list.
                if (!_this.isDraggingAllowed || _this.isDrawing) {
                    return;
                }
                var el = document.elementsFromPoint(event.x, event.y)[3];
                if (el) {
                    if (["span"].indexOf(el.nodeName.toLowerCase()) === -1) {
                        _this.repaint();
                        _this.drawingContainer.style.cursor = "crosshair";
                        return;
                    }
                    _this.drawingContainer.style.cursor = "pointer";
                    var rect = el.getBoundingClientRect();
                    _this.annotationHelper.annotationArea = {
                        x: rect.left + document.documentElement.scrollLeft,
                        y: rect.top + document.documentElement.scrollTop,
                        width: rect.width,
                        height: rect.height
                    };
                    _this.repaint();
                    if (_this.annotationHelper.annotationType === AnnotationType.Highlight) {
                        if (_this.annotationHelper.annotationArea && _this.drawingCTX) {
                            _this.paintLines(_this.annotationHelper.annotationArea.x, _this.annotationHelper.annotationArea.y, _this.annotationHelper.annotationArea.width, _this.annotationHelper.annotationArea.height);
                            _this.drawingCTX.clearRect(_this.annotationHelper.annotationArea.x, _this.annotationHelper.annotationArea.y, _this.annotationHelper.annotationArea.width, _this.annotationHelper.annotationArea.height);
                        }
                    }
                    _this.paintArea();
                    if (_this.annotationHelper.annotationType === AnnotationType.Blackout && _this.drawingCTX) {
                        _this.drawingCTX.fillStyle = "rgba(0,0,0,.5)";
                        _this.drawingCTX.fillRect(_this.annotationHelper.annotationArea.x, _this.annotationHelper.annotationArea.y, _this.annotationHelper.annotationArea.width, _this.annotationHelper.annotationArea.height);
                    }
                    _this.paintArea(AnnotationType.Blackout);
                }
            };
            this.drawListener = function (event) {
                event.preventDefault();
                if (_this.isDrawing) {
                    _this.area.width = event.clientX - _this.area.x + document.documentElement.scrollLeft;
                    _this.area.height = event.clientY - _this.area.y + document.documentElement.scrollTop;
                    // TODO: constant '4' should be lineWidth - also should be optional
                    if (_this.area.x + _this.area.width > document.documentElement.scrollWidth) {
                        _this.area.width = document.documentElement.scrollWidth - _this.area.x - 4;
                    }
                    if (_this.area.x + _this.area.width < 0) {
                        _this.area.width = -_this.area.x + 4;
                    }
                    if (_this.area.y + _this.area.height > document.documentElement.scrollHeight) {
                        _this.area.height = document.documentElement.scrollHeight - _this.area.y - 4;
                    }
                    if (_this.area.y + _this.area.height < 0) {
                        _this.area.height = -_this.area.y + 4;
                    }
                    _this.resetDrawBoard();
                    _this.paintHighlightLines();
                    if (_this.annotationHelper.annotationType === AnnotationType.Highlight &&
                        Math.abs(_this.area.width) > 6 &&
                        Math.abs(_this.area.height) > 6) {
                        _this.paintLines(_this.area.x, _this.area.y, _this.area.width, _this.area.height);
                        _this.drawingCTX &&
                            _this.drawingCTX.clearRect(_this.area.x, _this.area.y, _this.area.width, _this.area.height);
                    }
                    _this.paintArea();
                    _this.paintArea(AnnotationType.Blackout);
                    if (_this.annotationHelper.annotationType === AnnotationType.Blackout &&
                        Math.abs(_this.area.width) > 6 &&
                        Math.abs(_this.area.height) > 6) {
                        if (_this.drawingCTX) {
                            _this.drawingCTX.fillStyle = "rgba(0,0,0,.5)";
                            _this.drawingCTX.fillRect(_this.area.x, _this.area.y, _this.area.width, _this.area.height);
                        }
                    }
                }
            };
            this.showToolBar = function () {
                _this.isDrawingAllowed = true;
                _this.drawingContainer.classList.add("active");
                _this.toolbarAlertInfo();
                // this.options.dialogContainer.style.display = "none";
                _this.updateDrawing(false);
                _this.createToolBar();
                _this.drawingContainer.style.zIndex = '100';
                document.addEventListener("mousemove", _this.highlightAnnotation);
                document.addEventListener("click", _this.saveHighlightAnnotation);
            };
            this.hideToolBar = function () {
                _this.isDrawingAllowed = false;
                _this.drawingContainer.classList.remove("active");
                _this.rootContainer.removeChild(_this.toolbarContainer);
                _this.drawingContainer.style.zIndex = 'auto';
                _this.updateDrawing(true);
                document.removeEventListener("mousemove", _this.highlightAnnotation);
                document.removeEventListener("click", _this.saveHighlightAnnotation);
                _this.prepareShot();
            };
            this.setScrollPositions = function () {
                var x = -document.documentElement.scrollLeft;
                var y = -document.documentElement.scrollTop;
                _this.drawingContainer.style.left = x + "px";
                _this.drawingContainer.style.top = y + "px";
                _this.annotationHelper.container.style.left = x + "px";
                _this.annotationHelper.container.style.top = y + "px";
            };
            this.resizeHelpers = function () {
                var height = document.documentElement.scrollHeight;
                var width = document.documentElement.scrollWidth;
                _this.drawingContainer.height = height;
                _this.drawingContainer.width = width;
                _this.annotationHelper.container.style.height = height + "px";
                _this.annotationHelper.container.style.width = width + "px";
                _this.repaint();
            };
            this.startDragToolbar = function (event) {
                if (!_this.isDragging) {
                    _this.isDragging = true;
                    _this.toolbarPosition.x = event.clientX;
                    _this.toolbarPosition.y = event.clientY;
                    var rect = _this.toolbarContainer.getBoundingClientRect();
                    _this.toolbarPosition.boundary.xNeg = -rect.left;
                    _this.toolbarPosition.boundary.xPos = document.documentElement.clientWidth - rect.right;
                    _this.toolbarPosition.boundary.yNeg = -rect.top;
                    _this.toolbarPosition.boundary.yPos = document.documentElement.clientHeight - rect.bottom;
                }
            };
            this.dragToolbar = function (event) {
                if (_this.isDragging) {
                    event.preventDefault();
                    var nextX = event.clientX - _this.toolbarPosition.x;
                    var nextY = event.clientY - _this.toolbarPosition.y;
                    if (nextX < _this.toolbarPosition.boundary.xNeg) {
                        nextX = _this.toolbarPosition.boundary.xNeg;
                    }
                    if (nextX > _this.toolbarPosition.boundary.xPos) {
                        nextX = _this.toolbarPosition.boundary.xPos;
                    }
                    if (nextY < _this.toolbarPosition.boundary.yNeg) {
                        nextY = _this.toolbarPosition.boundary.yNeg;
                    }
                    if (nextY > _this.toolbarPosition.boundary.yPos) {
                        nextY = _this.toolbarPosition.boundary.yPos;
                    }
                    nextX = Math.round(nextX);
                    nextY = Math.round(nextY);
                    _this.toolbarPosition.nextTx = "translate(" + nextX + "px, " + nextY + "px)";
                    _this.toolbarContainer.style.transform = _this.toolbarPosition.currTx + " " + _this.toolbarPosition.nextTx;
                    _this.isDraggingAllowed = true;
                }
            };
            this.stopDragToolbar = function (event) {
                _this.isDragging = false;
                if (_this.isDraggingAllowed) {
                    _this.toolbarPosition.currTx = _this.toolbarPosition.currTx + " " + _this.toolbarPosition.nextTx;
                    _this.isDraggingAllowed = false;
                }
            };
            this.destroy = function () {
                _this.reset();
                window.removeEventListener("resize", _this.resizeHelpers);
                _this.drawingContainer.removeEventListener("mousedown", _this.drawStartListener);
                document.removeEventListener("mouseup", _this.drawStopListener);
                document.removeEventListener("mousemove", _this.drawListener);
                document.removeEventListener("mousemove", _this.highlightAnnotation);
                document.removeEventListener("click", _this.saveHighlightAnnotation);
                _this.draggerTip.removeEventListener("mousemove", _this.dragToolbar);
                document.removeEventListener("mouseup", _this.stopDragToolbar);
                document.removeEventListener("mousedown", _this.startDragToolbar);
                document.body.removeChild(_this.rootContainer);
            };
            this.setOptions(options);
        }
        Shotify.prototype.init = function () {
            this.reset();
            this.setIgnoreAttributes();
            this.setupContainers();
            this.setScrollPositions();
            this.attachScrollListener();
            this.prepareShot();
        };
        Shotify.prototype.attachScrollListener = function () {
            window.addEventListener("scroll", this.setScrollPositions);
        };
        Shotify.prototype.setOptions = function (options) {
            this.options = options;
            this.html2canvasOptions = __assign({ allowTaint: true }, (options.html2canvasOptions || {}));
        };
        Shotify.prototype.setupContainers = function () {
            var rootContainer = document.createElement("div");
            rootContainer.setAttribute('data-shotify', "true");
            this.rootContainer = rootContainer;
            var annotationHelpersContainer = document.createElement("div");
            annotationHelpersContainer.classList.add("cv-preview__helpers");
            annotationHelpersContainer.style.width = document.documentElement.scrollWidth + "px";
            annotationHelpersContainer.style.height = document.documentElement.scrollHeight + "px";
            this.annotationHelper.container = annotationHelpersContainer;
            rootContainer.appendChild(annotationHelpersContainer);
            var drawingContainer = document.createElement("canvas");
            drawingContainer.classList.add("cv-preview__draw-area");
            drawingContainer.width = document.documentElement.scrollWidth;
            drawingContainer.height = document.documentElement.scrollHeight;
            this.drawingContainer = drawingContainer;
            this.drawingCTX = this.drawingContainer.getContext("2d");
            rootContainer.appendChild(drawingContainer);
            drawingContainer.addEventListener("mousedown", this.drawStartListener);
            this.options.previewContainer.addEventListener("click", this.showToolBar);
            document.addEventListener("mouseup", this.drawStopListener);
            document.addEventListener("mousemove", this.drawListener);
            window.addEventListener("resize", this.resizeHelpers);
            this.resetDrawBoard();
            document.body.appendChild(this.rootContainer);
        };
        Shotify.prototype.createHelperDiv = function (data) {
            var _this = this;
            var divElem = document.createElement("div");
            divElem.className = this.annotationHelper.annotationType ? this.options.classes.highlight : this.options.classes.blackout;
            divElem.style.position = "absolute";
            divElem.style.left = data.x + "px";
            divElem.style.top = data.y + "px";
            divElem.style.width = data.width + "px";
            divElem.style.height = data.height + "px";
            divElem.style.zIndex = "101";
            divElem.setAttribute("id", "" + data.id);
            var innerDivElem = document.createElement("div");
            innerDivElem.style.width = data.width - 2 + "px";
            innerDivElem.style.height = data.height - 2 + "px";
            innerDivElem.style.margin = "1px";
            var removeElem = document.createElement("div");
            removeElem.className += this.options.classes.remove_action;
            removeElem.innerHTML = "<i class=\"" + this.options.classes.remove_icon + "\"></i>";
            removeElem.style.position = "absolute";
            removeElem.style.right = removeElem.style.top = "0";
            removeElem.addEventListener("click", function (event) {
                _this.annotationHelper.container.removeChild(divElem);
                _this.annotationHelper.annotations.splice(_this.annotationHelper.annotations.findIndex(function (annotation) { return annotation.id === data.id; }), 1);
                _this.repaint();
            });
            divElem.addEventListener("mouseleave", function (event) {
                if (_this.isDrawingAllowed && !_this.isDrawing && divElem.hasChildNodes()) {
                    var child = divElem.lastElementChild;
                    while (child) {
                        divElem.removeChild(child);
                        child = divElem.lastElementChild;
                    }
                    _this.repaint();
                }
            });
            divElem.addEventListener("mouseenter", function (event) {
                if (_this.isDrawingAllowed && !_this.isDrawing) {
                    divElem.appendChild(innerDivElem);
                    divElem.appendChild(removeElem);
                    if (data.type === AnnotationType.Blackout) {
                        _this.resetDrawBoard();
                        _this.paintHighlightLines();
                        _this.paintArea();
                        if (_this.drawingCTX) {
                            _this.drawingCTX.clearRect(data.x, data.y, data.width, data.height);
                            _this.drawingCTX.fillStyle = "rgba(0,0,0,.75)";
                            _this.drawingCTX.fillRect(data.x, data.y, data.width, data.height);
                            _this.annotationHelper.annotations
                                .filter(function (annotation) {
                                return annotation.type === AnnotationType.Blackout && annotation.id !== annotation.id;
                            })
                                .forEach(function (annotation) {
                                if (_this.drawingCTX) {
                                    _this.drawingCTX.fillStyle = "rgba(0,0,0,1)";
                                    _this.drawingCTX.fillRect(annotation.x, annotation.y, annotation.width, annotation.height);
                                }
                            });
                        }
                    }
                }
            });
            this.annotationHelper.container.appendChild(divElem);
            return divElem;
        };
        Shotify.prototype.createToolBar = function () {
            var _this = this;
            var toolbarElem = document.createElement("div");
            toolbarElem.className = this.options.classes.toolbar;
            toolbarElem.setAttribute('data-shotify', "true");
            var draggerTipElem = document.createElement("div");
            draggerTipElem.className = this.options.classes.grippy;
            draggerTipElem.innerHTML = "<i class=\"" + this.options.classes.grippy_icon + "\"></i>";
            document.addEventListener("mouseup", this.stopDragToolbar);
            document.addEventListener("mousedown", this.startDragToolbar);
            this.draggerTip = draggerTipElem;
            this.draggerTip.addEventListener("mousemove", this.dragToolbar);
            toolbarElem.appendChild(this.draggerTip);
            var highlightButtonContainer = document.createElement("div");
            highlightButtonContainer.classList.add(this.options.classes.toolbar_action);
            var highlightButton = document.createElement("button");
            highlightButton.type = "button";
            highlightButton.className += this.options.classes.toolbar_action_highlight;
            highlightButton.addEventListener("click", function () { return (_this.annotationHelper.annotationType = AnnotationType.Highlight); });
            highlightButtonContainer.appendChild(highlightButton);
            toolbarElem.appendChild(highlightButtonContainer);
            var blackoutButtonContainer = document.createElement("div");
            blackoutButtonContainer.classList.add(this.options.classes.toolbar_action);
            var blackoutButton = document.createElement("button");
            blackoutButton.type = "button";
            blackoutButton.className += this.options.classes.toolbar_action_blackout;
            blackoutButton.addEventListener("click", function () { return (_this.annotationHelper.annotationType = AnnotationType.Blackout); });
            blackoutButtonContainer.appendChild(blackoutButton);
            toolbarElem.appendChild(blackoutButtonContainer);
            var doneButtonContainer = document.createElement("div");
            doneButtonContainer.classList.add(this.options.classes.toolbar_action);
            var doneButton = document.createElement("button");
            doneButton.innerText = "DONE";
            doneButton.type = "button";
            doneButton.className += this.options.classes.toolbar_action_done;
            doneButton.addEventListener("click", this.hideToolBar);
            doneButtonContainer.appendChild(doneButton);
            toolbarElem.appendChild(doneButtonContainer);
            this.toolbarContainer = toolbarElem;
            this.toolbarPosition.currTx = "translate(-50%, -50%)";
            this.rootContainer.appendChild(this.toolbarContainer);
        };
        Shotify.prototype.resetDrawBoard = function () {
            if (this.drawingCTX) {
                this.drawingCTX.clearRect(0, 0, this.drawingContainer.width, this.drawingContainer.height);
                this.drawingCTX.fillStyle = "rgba(102,102,102,.5)";
                this.drawingCTX.fillRect(0, 0, this.drawingContainer.width, this.drawingContainer.height);
            }
        };
        Shotify.prototype.fetchCurrWindowProps = function () {
            return {
                width: window.innerWidth,
                height: window.innerHeight,
                scrollX: window.pageXOffset,
                scrollY: window.pageYOffset,
                x: window.pageXOffset,
                y: window.pageYOffset
            };
        };
        Shotify.prototype.prepareShot = function () {
            var _this = this;
            this.html2canvasOptions = __assign(__assign({}, this.html2canvasOptions), this.fetchCurrWindowProps());
            this.repaint(false);
            if (this.previewCanvas) {
                this.options.previewContainer.removeChild(this.previewCanvas);
            }
            this.updateProcessing(true);
            html2canvas(document.body, this.html2canvasOptions)
                .then(function (canvas) {
                // To prevent lag
                _this.annotationHelper.annotations.forEach(function (annotation) {
                    if (annotation.element) {
                        annotation.element.style.zIndex = "auto";
                    }
                });
                setTimeout(function () {
                    _this.previewCanvas = _this.options.previewContainer.appendChild(canvas);
                    _this.repaint();
                    _this.updateProcessing();
                    _this.emitEvent('processed', _this.previewCanvas.toDataURL());
                }, 500);
            }).catch(function () {
                _this.updateProcessing();
                // TODO: emit error event
            });
        };
        Shotify.prototype.updateDrawing = function (state, emit) {
            if (state === void 0) { state = false; }
            this.emitEvent('drawing', state);
        };
        Shotify.prototype.updateProcessing = function (state, emit) {
            if (state === void 0) { state = false; }
            if (emit === void 0) { emit = true; }
            this.isProcessing = state;
            emit && this.emitEvent('processing', state);
        };
        Shotify.prototype.setIgnoreAttributes = function () {
            var ignoreElements = this.options.ignoreElements || [];
            ignoreElements.forEach(function (element) {
                element.setAttribute("data-html2canvas-ignore", "true");
            });
        };
        Shotify.prototype.emitEvent = function (eventType, payload) {
            if (typeof this.options.update === 'function') {
                this.options.update(eventType, payload);
            }
        };
        Shotify.prototype.resetArea = function () {
            this.area = {
                x: 0,
                y: 0,
                width: 0,
                height: 0
            };
        };
        Shotify.prototype.resetState = function () {
            this.isDrawing = false;
            this.isDragging = false;
            this.isDrawingAllowed = false;
            this.isDraggingAllowed = false;
        };
        Shotify.prototype.reset = function () {
            this.updateProcessing(false, false);
            this.toolbarPosition = {
                x: 0,
                y: 0,
                currTx: null,
                nextTx: null,
                boundary: {
                    xNeg: 0,
                    xPos: 0,
                    yNeg: 0,
                    yPos: 0
                }
            };
            this.resetArea();
            this.resetState();
            this.annotationHelper = new AnnotationHelper();
        };
        Shotify.prototype.repaint = function (includeHighlights) {
            if (includeHighlights === void 0) { includeHighlights = true; }
            this.resetDrawBoard();
            if (includeHighlights) {
                this.paintHighlightLines();
            }
            this.paintArea();
            this.paintArea(AnnotationType.Blackout);
        };
        Shotify.prototype.paintHighlightLines = function () {
            var _this = this;
            this.annotationHelper.annotations.forEach(function (annotation) {
                if (annotation.type === AnnotationType.Highlight) {
                    var x = annotation.x, y = annotation.y, height = annotation.height, width = annotation.width;
                    _this.paintLines(x, y, width, height);
                }
            });
        };
        Shotify.prototype.paintLines = function (x, y, width, height) {
            if (this.drawingCTX) {
                this.drawingCTX.strokeStyle = "#ffeb3b";
                this.drawingCTX.lineJoin = "bevel";
                this.drawingCTX.lineWidth = 4;
                this.drawingCTX.strokeRect(x, y, width, height);
                this.drawingCTX.lineWidth = 1;
            }
        };
        Shotify.prototype.toolbarAlertInfo = function () {
            var _this = this;
            if (this.isAlertInfoShown) {
                return;
            }
            this.isAlertInfoShown = true;
            var alertInfoElem = document.createElement('div');
            alertInfoElem.className += this.options.classes.alert;
            alertInfoElem.setAttribute("data-html2canvas-ignore", "true");
            alertInfoElem.innerText = 'Draw using yellow to highlight issues or black to hide sensitive info';
            this.rootContainer.appendChild(alertInfoElem);
            setTimeout(function () {
                _this.rootContainer.removeChild(alertInfoElem);
            }, 3000);
        };
        Shotify.prototype.paintArea = function (annotationType) {
            var _this = this;
            if (annotationType === void 0) { annotationType = AnnotationType.Highlight; }
            if (annotationType === AnnotationType.Highlight) {
                this.annotationHelper.annotations.forEach(function (annotation) {
                    var x = annotation.x, y = annotation.y, width = annotation.width, height = annotation.height;
                    if (annotation.type === AnnotationType.Highlight) {
                        _this.drawingCTX && _this.drawingCTX.clearRect(x, y, width, height);
                    }
                });
            }
            else {
                this.annotationHelper.annotations.forEach(function (annotation) {
                    var x = annotation.x, y = annotation.y, width = annotation.width, height = annotation.height;
                    if (annotation.type === AnnotationType.Blackout) {
                        if (_this.drawingCTX) {
                            _this.drawingCTX.fillStyle = "rgba(0,0,0,1)";
                            _this.drawingCTX.fillRect(x, y, width, height);
                        }
                    }
                });
            }
        };
        return Shotify;
    }());

    return Shotify;

}));
